package com.bonus.sgzb.machine.service;


import com.bonus.sgzb.machine.damain.MaPartType;

import java.util.List;

/**
 * 配件类型管理ma_part_type(MaPartType)表服务接口
 *
 * @author makejava
 * @since 2023-11-27 16:44:19
 */
public interface IPartTypeService {

    /**
     * 校验配件名称唯一性
     * @param maPartType
     * @return
     */
    boolean checkPaNameUnique(MaPartType maPartType);

    /**
     * 新增配件类型
     * @param maPartType
     * @return
     */
    int insertMaPart(MaPartType maPartType);

    /**
     * 查询配件类型列表
     * @param maPartType
     * @return
     */
    List<MaPartType> selectMaPartList(MaPartType maPartType);

    /**
     * 导出配件管理
     * @param maPartType
     * @return
     */
    List<MaPartType> selectMyPartTypeList(MaPartType maPartType);

    /**
     * 查询是否含有子集
     * @param paId
     * @return
     */
    boolean hasChildBypaId(Long paId);

    /**
     * 删除配件类型
     * @param paId
     * @return
     */
    int deletePaById(Long paId);
}


